==> openshift-model-hive-6.9.0-sources.jar: io/fabric8/openshift/api/model/hive/azure/v1/DiskEncryptionSetFluent.java <==
package io.fabric8.openshift.api.model.hive.azure.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class DiskEncryptionSetFluent<A extends DiskEncryptionSetFluent<A>> extends BaseFluent<A>{
  public DiskEncryptionSetFluent() {
  }
  
  public DiskEncryptionSetFluent(DiskEncryptionSet instance) {
    this.copyInstance(instance);
  }
  private String name;
  private String resourceGroup;
  private String subscriptionId;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(DiskEncryptionSet instance) {
    instance = (instance != null ? instance : new DiskEncryptionSet());
  
    if (instance != null) {
        this.withName(instance.getName());
        this.withResourceGroup(instance.getResourceGroup());
        this.withSubscriptionId(instance.getSubscriptionId());
        this.withName(instance.getName());
        this.withResourceGroup(instance.getResourceGroup());
        this.withSubscriptionId(instance.getSubscriptionId());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public String getResourceGroup() {
    return this.resourceGroup;
  }
  
  public A withResourceGroup(String resourceGroup) {
    this.resourceGroup=resourceGroup; return (A) this;
  }
  
  public boolean hasResourceGroup() {
    return this.resourceGroup != null;
  }
  
  public String getSubscriptionId() {
    return this.subscriptionId;
  }
  
  public A withSubscriptionId(String subscriptionId) {
    this.subscriptionId=subscriptionId; return (A) this;
  }
  
  public boolean hasSubscriptionId() {
    return this.subscriptionId != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DiskEncryptionSetFluent that = (DiskEncryptionSetFluent) o;
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    if (!java.util.Objects.equals(resourceGroup, that.resourceGroup)) return false;
  
    if (!java.util.Objects.equals(subscriptionId, that.subscriptionId)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(name,  resourceGroup,  subscriptionId,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (resourceGroup != null) { sb.append("resourceGroup:"); sb.append(resourceGroup + ","); }
    if (subscriptionId != null) { sb.append("subscriptionId:"); sb.append(subscriptionId + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> openshift-model-hive-6.9.1-sources.jar: io/fabric8/openshift/api/model/hive/azure/v1/DiskEncryptionSetFluent.java <==
package io.fabric8.openshift.api.model.hive.azure.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class DiskEncryptionSetFluent<A extends DiskEncryptionSetFluent<A>> extends BaseFluent<A>{
  public DiskEncryptionSetFluent() {
  }
  
  public DiskEncryptionSetFluent(DiskEncryptionSet instance) {
    this.copyInstance(instance);
  }
  private String name;
  private String resourceGroup;
  private String subscriptionId;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(DiskEncryptionSet instance) {
    instance = (instance != null ? instance : new DiskEncryptionSet());
    if (instance != null) {
          this.withName(instance.getName());
          this.withResourceGroup(instance.getResourceGroup());
          this.withSubscriptionId(instance.getSubscriptionId());
          this.withName(instance.getName());
          this.withResourceGroup(instance.getResourceGroup());
          this.withSubscriptionId(instance.getSubscriptionId());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name = name;
    return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public String getResourceGroup() {
    return this.resourceGroup;
  }
  
  public A withResourceGroup(String resourceGroup) {
    this.resourceGroup = resourceGroup;
    return (A) this;
  }
  
  public boolean hasResourceGroup() {
    return this.resourceGroup != null;
  }
  
  public String getSubscriptionId() {
    return this.subscriptionId;
  }
  
  public A withSubscriptionId(String subscriptionId) {
    this.subscriptionId = subscriptionId;
    return (A) this;
  }
  
  public boolean hasSubscriptionId() {
    return this.subscriptionId != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DiskEncryptionSetFluent that = (DiskEncryptionSetFluent) o;
    if (!java.util.Objects.equals(name, that.name)) return false;
    if (!java.util.Objects.equals(resourceGroup, that.resourceGroup)) return false;
    if (!java.util.Objects.equals(subscriptionId, that.subscriptionId)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(name,  resourceGroup,  subscriptionId,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (resourceGroup != null) { sb.append("resourceGroup:"); sb.append(resourceGroup + ","); }
    if (subscriptionId != null) { sb.append("subscriptionId:"); sb.append(subscriptionId + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
